@@ -50,7 +50,7 @@ import org.apache.catalina.util.CharsetMapper;
  * <p>
  *
  * @author Craig R. McClanahan
- * @version $Revision: 750918 $ $Date: 2009-03-06 15:34:44 +0100 (Fri, 06 Mar 2009) $
+ * @version $Id: Context.java 1137629 2011-06-20 13:38:23Z markt $
  */
 
 public interface Context extends Container {
@@ -65,6 +65,11 @@ public interface Context extends Container {
     public static final String RELOAD_EVENT = "reload";
 
 
+    /**
+     * Container event for changing the ID of a session.
+     */
+    public static final String CHANGE_SESSION_ID_EVENT = "changeSessionId";
+
     // ------------------------------------------------------------- Properties
 
 
@@ -181,6 +186,26 @@ public interface Context extends Container {
      */
     public void setCookies(boolean cookies);
 
+    
+    /**
+     * Gets the name to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @return  The value of the default session cookie name or null if not
+     *          specified
+     */
+    public String getSessionCookieName();
+    
+    
+    /**
+     * Sets the name to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @param sessionCookieName   The name to use
+     */
+    public void setSessionCookieName(String sessionCookieName);
+
+    
     /**
      * Gets the value of the use HttpOnly cookies for session cookies flag.
      * 
@@ -198,12 +223,50 @@ public interface Context extends Container {
      */
     public void setUseHttpOnly(boolean useHttpOnly);
     
+    
+    /**
+     * Gets the domain to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @return  The value of the default session cookie domain or null if not
+     *          specified
+     */
+    public String getSessionCookieDomain();
+    
+    
+    /**
+     * Sets the domain to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @param sessionCookieDomain   The domain to use
+     */
+    public void setSessionCookieDomain(String sessionCookieDomain);
+
+    
+    /**
+     * Gets the path to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @return  The value of the default session cookie path or null if not
+     *          specified
+     */
+    public String getSessionCookiePath();
+    
+    
+    /**
+     * Sets the path to use for session cookies. Overrides any setting that
+     * may be specified by the application.
+     * 
+     * @param sessionCookiePath   The path to use
+     */
+    public void setSessionCookiePath(String sessionCookiePath);
+
+    
     /**
      * Return the "allow crossing servlet contexts" flag.
      */
     public boolean getCrossContext();
 
-
     
     /**
      * Return the alternate Deployment Descriptor name.
@@ -267,6 +330,35 @@ public interface Context extends Container {
      * @param docBase The new document root
      */
     public void setDocBase(String docBase);
+    
+    
+    /**
+     * Is URL rewriting disabled?
+     * URL rewriting is an optional component of the servlet 2.5 specification.
+     * However if set to true this will be non-compliant with the specification
+     * as the specification requires that there <b>must</b> be a way to retain
+     * sessions if the client doesn't allow session cookies.
+     * 
+     * @return true If URL rewriting is disabled.
+     * 
+     * @see <a href="http://jcp.org/aboutJava/communityprocess/mrel/jsr154/index2.html">Servlet
+     *      2.5 Specification. Sections SRV.7.1.3 and SRV.7.1.4</a>
+     * @see javax.servlet.http.HttpServletResponse#encodeURL(String) encodeURL
+     * @see javax.servlet.http.HttpServletResponse#encodeRedirectURL(String)
+     *      encodeRedirectURL
+     */
+    public boolean isDisableURLRewriting();
+    
+    /**
+     * Is URL rewriting disabled?
+     * URL rewriting is an optional component of the servlet 2.5 specification.
+     * However if set to true this will be non-compliant with the specification
+     * as the specification requires that there <b>must</b> be a way to retain
+     * sessions if the client doesn't allow session cookies.
+     *
+     * @param disable True to disable URL Rewriting. Default <b>false</b>.
+     */
+    public void setDisableURLRewriting(boolean disable);
 
 
     /**
@@ -1037,10 +1129,6 @@ public interface Context extends Container {
      * @param xmlNamespaceAware true to enable namespace awareness
      */
     public void setXmlNamespaceAware(boolean xmlNamespaceAware);
-    /**
-     * Get the server.xml <context> attribute's xmlValidation.
-     * @return true if validation is enabled.
-     */
      
 
     /**
@@ -1052,15 +1140,15 @@ public interface Context extends Container {
 
 
     /**
-     * Get the server.xml <context> attribute's webXmlValidation.
+     * Get the validation feature of the XML parser used when
+     * parsing tlds files. 
      * @return true if validation is enabled.
-     *
      */
     public boolean getTldValidation();
 
 
     /**
-     * Get the server.xml <host> attribute's xmlNamespaceAware.
+     * Get the server.xml &lt;host&gt; attribute's xmlNamespaceAware.
      * @return true if namespace awarenes is enabled.
      */
     public boolean getTldNamespaceAware();
@@ -1072,7 +1160,5 @@ public interface Context extends Container {
      * @param tldNamespaceAware true to enable namespace awareness
      */
     public void setTldNamespaceAware(boolean tldNamespaceAware);
-
-
 }
 
